@@ -228,7 +228,7 @@ class Crawler:
                     lxml_tree.xpath(comment_xpath_dict["push_ip_date_time"]),
                 ]
                 for idx, push_tag, push_user_id, push_content, push_ip_date_time in zip(*comment_data):
-                    _push_tag = push_tag.text
+                    _push_tag = push_tag.text.replace(" ", "")
                     _push_user_id = push_user_id.text
                     _push_content = push_content.text
                     _push_ip_date_time = re.sub("[\n]", "", push_ip_date_time.text)
